@@ -219,7 +219,7 @@ class OpenEphysBase(object):
 		actually plotting the maps and/ or extracting data from them without plotting
 		"""
 		if self.kilodata is None:
-			self.loadKilo(kwargs)
+			self.loadKilo(**kwargs)
 		if ( 'ppm' in kwargs.keys() ):
 			ppm = kwargs['ppm']
 		else:
@@ -252,7 +252,7 @@ class OpenEphysBase(object):
 
 	def plotXCorrs(self, **kwargs):
 		if self.kilodata is None:
-			self.loadKilo(kwargs)
+			self.loadKilo(**kwargs)
 		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
 		corriter = SpikeCalcsGeneric(self.kilodata.spk_times)
 		corriter.spk_clusters = self.kilodata.spk_clusters
@@ -362,7 +362,7 @@ class OpenEphysBase(object):
 		"""
 
 		if self.kilodata is None:
-			self.loadKilo(kwargs)
+			self.loadKilo(**kwargs)
 		if ( 'ppm' in kwargs.keys() ):
 			ppm = kwargs['ppm']
 		else:
@@ -439,7 +439,7 @@ class OpenEphysBase(object):
 		ax.set_xlabel('Time(s)')
 		ax.set_ylabel('Frequency(Hz)')
 
-	def plotPSTH(self):
+	def plotPSTH(self, **kwargs):
 		"""Plots the peri-stimulus time histogram for all the 'good' clusters
 
 		Given some data has been recorded in the ttl channel, this method will plot
@@ -449,7 +449,7 @@ class OpenEphysBase(object):
 		self.__loadSettings__()
 		self.settings.parseStimControl()
 		if self.kilodata is None:
-			self.loadKilo(kwargs)
+			self.loadKilo(**kwargs)
 		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
 		spk_times = (self.kilodata.spk_times.T[0] / 3e4) + self.ts[0] # in seconds
 		S = SpikeCalcsGeneric(spk_times)
@@ -468,9 +468,9 @@ class OpenEphysBase(object):
 		event_ts = self.ttl_timestamps[2::2] # this is because some of the trials have two weird events logged at about 2-3 minutes in...
 		E.plotEventEEG(event_ts)
 
-	def plotWaves(self):
+	def plotWaves(self, **kwargs):
 		if self.kilodata is None:
-			self.loadKilo(kwargs)
+			self.loadKilo(**kwargs)
 		if self.rawData is None:
 			print("Loading raw data...")
 			self.load(loadraw=True)
@@ -808,7 +808,6 @@ class OpenEphysNWB(OpenEphysBase):
 			self.xy = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['data'])
 
 			self.xyTS = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['timestamps'])
-			self.xyTS = self.xyTS - (self.xy[:,2] / 1e6)
 			self.xy = self.xy[:,0:2]
 		except:
 			self.xy = None
@@ -901,7 +900,7 @@ class OpenEphysBinary(OpenEphysBase):
 		self.path2LFPdata = None
 		self.rawData = None
 
-	def load(self, pname_root=None, experiment_name='experiment1', recording_name='recording1', loadraw=False):
+	def load(self, pname_root=None, experiment_name='experiment1', recording_name='recording1', loadraw=False, n_channels=64):
 		"""
 		Loads data recorded in the OE 'flat' binary format.
 
@@ -948,7 +947,6 @@ class OpenEphysBinary(OpenEphysBase):
 			self.xyTS = pos_ts / 30.0 / 1000.0
 
 		ap_sample_rate = 30000
-		n_channels = 32
 		trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(self.path2APdata, 'continuous.dat'), n_channels, ap_sample_rate)
 		
 		if loadraw:
@@ -968,6 +966,7 @@ class OpenEphysBinary(OpenEphysBase):
 					start_val = line[idx + len('start time: '):-1]
 					tmp = start_val.split('@')
 					recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
+			self.xyTS = self.xyTS - self.recording_start_time # ensure pos timestamps are zeroed
 		else:
 			recording_start_time = self.xyTS[0]
 		self.recording_start_time = recording_start_time
@@ -996,7 +995,7 @@ class OpenEphysBinary(OpenEphysBase):
 		np.savetxt('position.txt', out, delimiter=',', fmt=['%3.3i','%3.3i','%3.3f'])
 
 	def loadKilo(self, **kwargs):
-		super().loadKilo()
+		super().loadKilo(**kwargs)
 
 	def plotPos(self, jumpmax=None, show=True):
 		xy = super().plotPos(jumpmax, show)
